%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Function:        anylyse                                             %
%  Description:     Fait le rflextion au rtro est analyse le resultat %
%  Dependicit:     retro(), refrac(), reflec(), save_refraxion,        %
%                   mirror_reflexion(), polybox                         %
%  Auteur:          Stefan Bracher                                      %
%  Date:            31.10.2006                                          %
%  Statut:          complt                                             %
%                                                                       %
%  Syntaxe:                                                             %
%  [trajet_optique, angle, distance]=analyse(a0, b0, n_air_, n_verre, T, size) %
%                                                                       %
%  Input:          a0:  un point sur le faisceau incident               %
%                  b0:  vecteur du faisceau incident                    %
%                  n:   la normale  la surface                         %
%                  n_air:  index de rfraction d'air                    %
%                  n_verre:  index de rfraction de verre               %
%                                                                       %
%  Output:         trajet_optique: Le trajet optique du faisceau        %
%                  angle: l'angle entre le faisceau avant et aprs      %
%                         rfraction                                    %
%                  distance:  la distance entre le faisceau avant et    %
%                              aprs rfraction                         % 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [trajet_optique, angle, distance]=analyse(a0, b0, n_air, n_verre, T, size)

   [a1, a2, b2, l_int]=retro(a0, b0, n_air, n_verre, T, size);
                % La rflexion au rtro
                
   % Le trajet optique   
   o_a=norm(a1-a0);     % le chemin du laser au rtro
   [a3, b3] = reflec(a2, b2, a0, b0);          % Reflection au plan au se trouve le laser
   o_b=norm(a3-a2);     % le chemin du rtro au plan du laser
   trajet_optique=o_a+o_b+l_int;  % Le trajet optique complt        
   
   angle=acos(dot(b0, b2)/(norm(b0)*norm(b2)));   % L'angle entre les 
                                                  % faisceaux (parallelisme)
                                                  
   distance=sqrt((norm(a2-a1))^2-(norm(dot(a2-a1, b0)))^2);
                        % La distance entre le point a2 et le faisceau
                        % entrant = La distance entre les deux faisceaux