%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Syript:          main                                                %
%  Description:     Etude du rtro-rflecteur                           %
%  Dependicit:     refrac(), regflec(), retro(), mirror_reflexion(),   %
%                   save_refraction(), trans_hom_point, trans_hom_vec() %
%  Auteur:          Stefan Bracher                                      %
%  Date:            31.10.2006                                          %
%  Statut:          complet                                             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%---Initiation-----------------------------------------------------------
clear all;
%------------------------------------------------------------------------

%---Paramtres-----------------------------------------------------------
% ! ATTENTION si le parantres sont chang, il faut peut etre           
%   enlever les definitions des axis(...) lors de l'affigage, pour voir 
%   tout les rsultats!

n_air=1;        % L'index optique d'air
n_verre=1.5;    % L'index optique de verre
size=50;        % dimensions du rtro (longeurs du coins de cube)
T_init=roty4(atan2(0.5*sqrt(2), 1))*rotz4(-pi/4);
                    % Positionemen initiale avec face d'entrace normale au 
                    % faiseau entrant (qui est parallle  l'axe x pour que
                    % des rotations autour de y et z peuvent entre
                    % utilises pour l'analyse
% (Verification avec la ligne suivante)
%trans_hom_vec([1 1 1]', inv(T_init)) = [sqrt(3), 0 0]'                    

a0=[1000, 10, 0]'; % La pointe du laser 
b0=[-1 0 0]';     % La direction du laser

deplacement_max=80;     % Dplacement maximale
rotation_max=pi/2;      % Rotation max
steps=160;              % Number of intermediate steps
stepsize=deplacement_max/steps;
anglestep=rotation_max/steps;
%------------------------------------------------------------------------


%----Dplacement lateral selon y----------------------------------------
for i=0:steps    % Boucle pour le dplacement
   deplacement(i+1)=-deplacement_max/2+i*stepsize;  % Le dplacement
   % Transformation homogne du dplaceent
   L=[1 0 0 0; 0 1 0 deplacement(i+1); 0 0 1 0; 0 0 0 1];
   T=L*T_init;  % La position du rtro      

   % Rflexion au rtro et analyse
   [trajet_optique(i+1), angle(i+1), distance(i+1)]=analyse(a0, b0, n_air, n_verre, T, size);

   i=i+1;   % Incrementer le comptezr
end

%...Affichage des rsultats...
figure
plot(deplacement, trajet_optique);
title('le trajet optique [dplacement latral au faisceau (y)]')
xlabel('dplacenet lateral [mm]')
ylabel('trajet optique [mm]')
axis([-deplacement_max/2 deplacement_max/2 1999.9999 2000.0001])

figure
plot(deplacement, angle);
title('angle entre les faisceaux (parallelisme) [dplacement latral au faisceau (y)]')
xlabel('dplacenet lateral [mm] [dplacement latral au faisceau]')
ylabel('angle [rad]')
axis([-deplacement_max/2 deplacement_max/2 3 3.5])

figure
plot(deplacement, distance);
title('distance sparant les faisceaux [dplacement latral au faisceau (y)]')
xlabel('dplacenet lateral [mm]')
ylabel('distance [mm]')
%..................................
%------------------------------------------------------------------------

%----Rotation autour un axe perpendiculair au faisceau -> z-------------
for i=0:steps    % Boucle pour le dplacement
   rot_angle(i+1)=-rotation_max/2+i*anglestep;  % L'angle de rotation
   T=rotz4(rot_angle(i+1))*T_init;  % La position du rtro      

   % Rflexion au rtro et analyse
   [trajet_optique(i+1), angle(i+1), distance(i+1)]=analyse(a0, b0, n_air, n_verre, T, size);

   i=i+1;   % Incrementer le compteur  
end

%...Affichage des rsultats...
figure
plot(rot_angle, trajet_optique);
title('le trajet optique [rotation autour d un axe perpendiculaire (axe z)]')
xlabel('angle de rotation [rad]')
ylabel('trajet optique [mm]')
axis([-rotation_max/2 rotation_max/2 2000 2005])

figure
plot(rot_angle, angle);
title('angle entre les faisceaux (parallelisme) [rotation autour d un axe perpendiculaire (axe z)]')
xlabel('angle de rotation [rad]')
ylabel('angle [rad]')
axis([-rotation_max/2 rotation_max/2 3 3.5])

figure
plot(rot_angle, distance);
title('distance sparant les faisceaux [rotation autour d un axe perpendiculaire (axe z)]')
xlabel('angle de rotation [rad]')
ylabel('distance [mm]')
axis([-rotation_max/2 rotation_max/2 0 30])
%..................................
%------------------------------------------------------------------------


%----Rotation autour un axe normale  la surface d'entre -> x-----------
for i=0:steps    % Boucle pour le dplacement
   rot_angle(i+1)=-rotation_max/2+i*anglestep;  % L'angle de rotation
   T=rotx4(rot_angle(i+1))*T_init;  % La position du rtro      
   
   % Rflexion au rtro et analyse
   [trajet_optique(i+1), angle(i+1), distance(i+1)]=analyse(a0, b0, n_air, n_verre, T, size);

   i=i+1;   % Incrementer le compteur
end

%...Affichage des rsultats...
figure
plot(rot_angle, trajet_optique);
title('le trajet optique [rotation autour de la normale  la face d entre (axe x)]')
xlabel('angle de rotation [rad]')
ylabel('trajet optique [mm]')
axis([-rotation_max/2 rotation_max/2 1999.9999 2000.0001])

figure
plot(rot_angle, angle);
title('angle entre les faisceaux (parallelisme) [rotation autour de la normale  la face d entre (axe x)]')
xlabel('angle de rotation [rad]')
ylabel('angle [rad]')
axis([-rotation_max/2 rotation_max/2 3 3.5])

figure
plot(rot_angle, distance);
title('distance sparant les faisceaux [rotation autour de la normale  la face d entre (axe x)]')
xlabel('angle de rotation [rad]')
ylabel('distance [mm]')
axis([-rotation_max/2 rotation_max/2 19.999 20.001])
%..................................
%------------------------------------------------------------------------