%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Function:        mirror_reflexion                                    %
%  Description:     Calcule la reflexion  un mirroir unidirectional,   %
%                   s'il y a lieu                                       %
%                   (Evite les messages d'erreur de reflec() )          %
%  Dependicit:     reflec()                                            %
%  Auteur:          Stefan Bracher                                      %
%  Date:            31.10.2006                                          %
%  Statut:          complt                                             %
%                                                                       %
%  Syntaxe: [a1, b1, a0a1, too_close]=mirror_reflexion(a0,b0,m,n, res)  %
%                                                                       %
%  Input:          a0:  un point sur le faisceau incident               %
%                  b0:  vecteur du faisceau incident                    %
%                  m:   un point sur le mirroir                         %
%                  n:   la normale  la surface du mirroir              %
%                  res: ce que est rgard tant zro            %
%                                                                       %
%  Output:         a1:  point d'incidence sur le miroir                 %
%                  b1:  vecteur du faisceau aprs rflection            %
%                  a0a1:  chemin optique de a0  a1                     %   
%                  too_close: =1: a0 est trop proche du mirroir         %
%                             =0: ne pas de probme                     %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [a1, b1, a0a1, too_close]=mirror_reflexion(a0,b0,m,n, res)

%-----CONSTANTES-----------------------------------
infinity=1e15;      % L'infinit
resolution=res;   % La rsulution minimale
%--------------------------------------------------

%----Mesures de scurit (DAU)---------------------
n=n/norm(n);       % Assurer que n est vecteur unitaire
b0=b0/norm(b0);    % Assurer que b0 est vecteur unitaire
%--------------------------------------------------

d=dot(n, (a0-m));       % La distance au mirroir

if ((dot(-n, b0)>0)&&(d>resolution))                    
        % b0 pointe vers la surface et ce ne trouve pas sur le mirroir
        [a1, b1] = reflec(a0, b0, m, n);          % Reflection au mirroir
        b1=b1/norm(b1);                           % Assurer que b1 est vecteur unitaire
        a0a1=norm(a1-a0);                         % Le vecteur du point p au point de rfraction avec X
else
        % le point a0 se trouve sur le mirroir ou le faisceau ne pointe pas
        % ver le mirroir
        a1=NaN;             % a1 n'existe pas
        b1=NaN;             % b1 n'existe pas
        a0a1=infinity;        % le chemin est infinit
end
    

if (d<resolution)    
    too_close=1;    % a0 est trop proche du mirroir (par exemple sur un coin du rtro)
else
    too_close=0;    % ne pas de problme
end
    