%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Function:        save_refraction                                     %
%  Description:     Calcule la refraction  une surface (unidirectional)%
%                   s'il y a lieu                                       %
%                   (Evite les messages d'erreur de refrac() )          %
%  Dependicit:     refrac()                                            %
%  Auteur:          Stefan Bracher                                      %
%  Date:            31.10.2006                                          %
%  Statut:          complt                                             %
%                                                                       %
%  Syntaxe: [a1, b1, a0a1, too_close]=save_refraction(a0,b0,m,n, n1, n2, res)%
%                                                                       %
%  Input:          a0:  un point sur le faisceau incident               %
%                  b0:  vecteur du faisceau incident                    %
%                  m:   un point sur la surface                         %
%                  n:   la normale  la surface                         %
%                  n1:  index de rfraction du premir element          %
%                  n2:  index de rfraction du deuxime element         %
%                  res: ce que est rgard tant zro                   %
%                                                                       %
%  Output:         a1:  point d'incidence sur la surface                %
%                  b1:  vecteur du faisceau aprs rfraction            %
%                  a0a1:  chemin optique de a0  a1                     %    
%                  too_close: =1: a0 est trop proche du mirroir         %
%                             =0: ne pas de probme                     %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [a1, b1, a0a1, too_close]=save_refraction(a0,b0,m,n, n1, n2, res)

%-----CONSTANTES-----------------------------------
infinity=1e15;      % L'infinit
resolution=res;   % La rsulution minimale
%--------------------------------------------------

%----Mesures de scurit (DAU)---------------------
n=n/norm(n);       % Assurer que n est vecteur unitaire
b0=b0/norm(b0);    % Assurer que b0 est vecteur unitaire
%--------------------------------------------------

d=dot(n, (a0-m));       % La distance  la surface

if ((dot(-n, b0)>0)&&(d>resolution))                    
        % b0 pointe vers la surface et ce ne trouve pas sur la surface
        [a1, b1] = refrac(a0,b0,n1,n2,m,n);       % Refraction
        b1=b1/norm(b1);                           % Assurer que b1 est vecteur unitaire
        a0a1=norm(a1-a0);                         % Le vecteur du point p au point de rfraction avec X
else
        % le point a0 se trouve sur la surface ou le faisceau ne pointe pas
        % ver la surface
        a1=NaN;             % a1 n'existe pas
        b1=NaN;             % b1 n'existe pas
        a0a1=infinity;      % le chemin est infinit
end
    

if (d<resolution)    
    too_close=1;    % a0 est trop proche de la surface (par exemple sur un coin du rtro)
else
    too_close=0;    % ne pas de problme
end